<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Faq_Builder_Ays
 * @subpackage Faq_Builder_Ays/public
 * @author     F.A.Q Builder Team <info@ays-pro.com>
 */
class Faq_Builder_Ays_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_style('ays_faq_font_awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/faq-builder-ays-public.css', array(), $this->version, 'all' );
        
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Faq_Builder_Ays_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Faq_Builder_Ays_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
        wp_enqueue_script('jquery');
        
		wp_enqueue_script( "ays_pb_bootstrap", 'https://stackpath.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array( 'jquery' ), $this->version, true );

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/faq-builder-ays-public.js', array( 'jquery' ), $this->version, false );

	}
    
    public function ays_initialize_faq_shortcode(){
        add_shortcode( 'ays_faq', array($this, 'ays_generate_faq') );
    }

    public function ays_generate_faq( $attr ){
        global $wpdb;
        $id = ( isset($attr['id']) ) ? absint( intval( $attr['id'] ) ) : null;
        
        $faq = $this->ays_get_faq_by_id($id);
        if(!$faq){
            return "[ays_faq id='".$id."']";
        }
        
        $faq_question_array = explode('***', $faq['questions']);
        $faq_answer_array = explode('***', $faq['answers']);
        
        $faq_view = "<div></div>";
        switch($faq['style']){
            case "default_arrow":
                 $faq_view = "<div class='ays-faq ays-faq-default'>
                        <div class='ays-title ays-title-default'>".stripcslashes(htmlentities($faq['title'])) ."</div>
                        <hr>
                        <div class='ays-description ays-description-default'>".wpautop($faq['description'])."</div>
                        <div class='ays-main' id='main'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                       $faq_view .= "<div class='ays-border-default' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-default'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-default'>
                                            <div class='ays_modal_element'>".stripcslashes(htmlentities( $faq_answer_array[$key] ))."</div>
                                        </div>
                                    </div>";
                    }
                $faq_view .= "</div></div>";
                break;
            case "plusminus":
                $faq_view = "<div class='ays-faq ays-faq-plusminus'>
                        <div class='ays-title ays-title-plusminus'>".stripcslashes(htmlentities( $faq['title'] ))."</div>
                        <div class='ays-description ays-description-plusminus'>".wpautop( $faq['description'] )."</div>
                        <div class='ays-main' id='main'>";
                    foreach($faq_question_array as $key => $question){
                        if($question == ""){
                            $question = "No question";
                        }
                       $faq_view .= "<div class='ays-border-plusminus' id='question_block_".$key."'>
                                        <div class='ays-question ays-question-plusminus'>
                                            <div class='ays-sub-question'>
                                                <label class='ays_faq_label'>".stripcslashes(htmlentities( $question ))."</label>
                                            </div>
                                        </div>
                                        <div class='ays-answer ays-answer-plusminus'>
                                            <div class='ays_modal_element'>".stripcslashes(htmlentities( $faq_answer_array[$key] ))."</div>
                                        </div>
                                    </div>";
                    }
                 $faq_view .= "</div></div>";
                break;
        }
        return $faq_view;
    }
    
    public function ays_get_faq_by_id( $id ) {
	    global $wpdb;

        $sql = "SELECT * FROM {$wpdb->prefix}ays_faqs WHERE id=" . absint( intval( $id ) );

        $result = $wpdb->get_row($sql, 'ARRAY_A');

        return $result;
    }
}